# Tensionflow

[![Build Status](https://travis-ci.org/Curly-Mo/tensionflow.svg?branch=master)](https://travis-ci.org/Curly-Mo/tensionflow)
[![Coverage](https://coveralls.io/repos/github/Curly-Mo/tensionflow/badge.svg)](https://coveralls.io/github/Curly-Mo/tensionflow)
[![Documentation](https://readthedocs.org/projects/tensionflow/badge/?version=latest)](https://tensionflow.readthedocs.org/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/tensionflow.svg)](https://pypi.python.org/pypi/tensionflow)
[![PyPI Pythons](https://img.shields.io/pypi/pyversions/tensionflow.svg)](https://pypi.python.org/pypi/tensionflow)
[![License](https://img.shields.io/pypi/l/tensionflow.svg)](https://github.com/Curly-Mo/tensionflow/blob/master/LICENSE)

A Tensorflow framework for working with audio data.

## Features

* TODO

## Usage

* TODO

## Install

```console
pip install tensionflow
```

## Documentation
See https://tensionflow.readthedocs.org/en/latest/

## Development
```console
pip install poetry
cd tensionflow
poetry install
```
### Run
To run cli entrypoint:
```console
poetry run tensionflow --help
```

### Tests
```console
poetry run tox
```

### Docker
To run with docker
```console
docker build -t tensionflow .
docker run tensionflow:latest tensionflow --help
```

## License
[LGPL-3.0](https://github.com/Curly-Mo/tensionflow/blob/master/LICENSE)
